@@ -501,9 +501,17 @@
   Drupal.CTools.AJAX.commands.redirect = function(data) {
     if (data.delay > 0) {
       setTimeout(function () {
-        location.href = data.url;
+        if (data.new_window) {
+          window.open(data.url, '_blank');
+        }
+        else {
+          location.href = data.url;
+        }
       }, data.delay);
     }
+    else if (data.new_window) {
+      window.open(data.url, '_blank');
+    }
     else {
       location.href = data.url;
     }
